@@ -1,8 +1,7 @@
 package Lemonldap::NG::Manager::Sessions;
 
-use 5.10.0;
-use utf8;
 use strict;
+use utf8;
 use Mouse;
 
 use Lemonldap::NG::Common::Session;
@@ -12,13 +11,15 @@ use Lemonldap::NG::Common::PSGI::Constants;
 use Lemonldap::NG::Common::Conf::ReConstants;
 use Lemonldap::NG::Common::IPv6;
 
-use feature 'state';
+#use feature 'state';
 
-extends 'Lemonldap::NG::Manager::Plugin',
-  'Lemonldap::NG::Common::Conf::AccessLib',
-  'Lemonldap::NG::Common::Session::REST';
+extends qw(
+  Lemonldap::NG::Manager::Plugin
+  Lemonldap::NG::Common::Session::REST
+  Lemonldap::NG::Common::Conf::AccessLib
+);
 
-our $VERSION = '2.0.8';
+our $VERSION = '2.0.10';
 
 #############################
 # I. INITIALIZATION METHODS #
@@ -55,7 +56,9 @@ sub init {
     $self->{ipField}              ||= 'ipAddr';
     $self->{multiValuesSeparator} ||= '; ';
     $self->{impersonationPrefix} = $conf->{impersonationPrefix} || 'real_';
-    $self->{hiddenAttributes} //= "_password";
+    $self->{hiddenAttributes} //= '_password';
+    $self->{hiddenAttributes} .= ' _session_id'
+      unless $conf->{displaySessionId};
     return 1;
 }
 
@@ -65,7 +68,7 @@ sub init {
 
 sub delOIDCConsent {
 
-    my ( $self, $req, $session, $skey ) = @_;
+    my ( $self, $req ) = @_;
 
     my $mod = $self->getMod($req)
       or return $self->sendError( $req, undef, 400 );
@@ -74,10 +77,15 @@ sub delOIDCConsent {
     my $epoch  = $params->{epoch};
     my $rp     = $params->{rp};
 
+    my $id = $req->params('sessionId')
+      or return $self->sendError( $req, 'sessionId is missing', 400 );
+
+    $req->parameters->set( 'sessionId', $self->_maybeDecryptSessionId($id) );
+
     if ( $rp =~ /\b[\w-]+\b/ and defined $epoch ) {
         $self->logger->debug(
             "Call procedure deleteOIDCConsent with RP=$rp and epoch=$epoch");
-        return $self->deleteOIDCConsent( $req, $session, $skey );
+        return $self->deleteOIDCConsent($req);
     }
     else {
         return $self->sendError( $req, undef, 400 );
@@ -241,8 +249,9 @@ sub sessions {
                 count    => scalar( @{ $r->{$uid} } ),
                 sessions => [
                     map { {
-                            session => $_->{_sessionId},
-                            date    => $_->{_utime}
+                            session =>
+                              $self->_maybeEncryptSessionId( $_->{_sessionId} ),
+                            date => $_->{_utime}
                         }
                     } @{ $r->{$uid} }
                 ]
@@ -349,7 +358,7 @@ qq{Use of an uninitialized attribute "$group" to group sessions},
     elsif ( my $f = $req->params('orderBy') ) {
         my @fields = split /,/, $f;
         my @r      = map {
-            my $tmp = { session => $_ };
+            my $tmp = { session => $self->_maybeEncryptSessionId($_) };
             foreach my $f (@fields) {
                 my $s = $f;
                 $s =~ s/^net(?:4|6|)\(([\w:]+)\)$/$1/;
@@ -390,7 +399,11 @@ qq{Use of an uninitialized attribute "$group" to group sessions},
     else {
         $res = [
             sort { $a->{date} <=> $b->{date} }
-              map { { session => $_, date => $res->{$_}->{_utime} } }
+              map { {
+                    session => $self->_maybeEncryptSessionId($_),
+                    date    => $res->{$_}->{_utime}
+                }
+              }
               keys %$res
         ];
     }
@@ -406,6 +419,45 @@ qq{Use of an uninitialized attribute "$group" to group sessions},
     );
 }
 
+sub session {
+    my ( $self, $req, $session, $skey ) = @_;
+
+    $session = $self->_maybeDecryptSessionId($session);
+    return $self->SUPER::session( $req, $session, $skey );
+}
+
+sub _maybeDecryptSessionId {
+    my ( $self, $session ) = @_;
+
+    if ( $self->{hiddenAttributes} =~ /\b_session_id\b/ ) {
+        $session =
+          Lemonldap::NG::Handler::Main->tsv->{cipher}->decryptHex($session);
+    }
+
+    return $session;
+}
+
+sub _maybeEncryptSessionId {
+    my ( $self, $session ) = @_;
+
+    if ( $self->{hiddenAttributes} =~ /\b_session_id\b/ ) {
+        $session =
+          Lemonldap::NG::Handler::Main->tsv->{cipher}->encryptHex($session);
+    }
+
+    return $session;
+}
+
+sub delSession {
+    my ( $self, $req ) = @_;
+    my $id = $req->params('sessionId')
+      or return $self->sendError( $req, 'sessionId is missing', 400 );
+
+    $req->parameters->set( 'sessionId', $self->_maybeDecryptSessionId($id) );
+
+    return $self->SUPER::delSession($req);
+}
+
 sub cmpIPv4 {
     my @a = split /\./, $_[0];
     my @b = split /\./, $_[1];
