@@ -1,17 +1,18 @@
 package Lemonldap::NG::Manager::Viewer;
 
-use 5.10.0;
+use strict;
 use utf8;
 use Mouse;
 use Lemonldap::NG::Common::Conf::Constants;
 use Lemonldap::NG::Common::UserAgent;
 use URI::URL;
 
-use feature 'state';
-
 extends 'Lemonldap::NG::Manager::Conf';
 
-our $VERSION = '2.0.4';
+has diffRule => ( is => 'rw', default => sub { 0 } );
+has brwRule  => ( is => 'rw', default => sub { 0 } );
+
+our $VERSION = '2.0.10';
 
 #############################
 # I. INITIALIZATION METHODS #
@@ -21,15 +22,40 @@ use constant defaultRoute => 'viewer.html';
 
 has ua => ( is => 'rw' );
 
-sub addRoutes {
+sub init {
     my ( $self, $conf ) = @_;
     $self->ua( Lemonldap::NG::Common::UserAgent->new($conf) );
+    my $hd = "Lemonldap::NG::Handler::PSGI::Main";
 
-    my $hiddenKeys  = $self->{viewerHiddenKeys} || '';
+    # Parse Diff activation rule
+    $conf->{viewerAllowDiff} //= 0;
+    $self->logger->debug(
+        "Diff activation rule -> " . ( $conf->{viewerAllowDiff} ) );
+    my $rule = $hd->buildSub( $hd->substitute( $conf->{viewerAllowDiff} ) );
+    unless ($rule) {
+        $self->logger->error(
+            "Bad Diff activation rule -> " . $hd->tsv->{jail}->error );
+        return 0;
+    }
+    $self->diffRule($rule);
+
+    # Parse Browser activation rule
+    $conf->{viewerAllowBrowser} //= 0;
+    $self->logger->debug(
+        "Browser activation rule -> " . ( $conf->{viewerAllowBrowser} ) );
+    $rule = $hd->buildSub( $hd->substitute( $conf->{viewerAllowBrowser} ) );
+    unless ($rule) {
+        $self->logger->error(
+            "Bad Browser activation rule -> " . $hd->tsv->{jail}->error );
+        return 0;
+    }
+    $self->brwRule($rule);
+
+    my $hiddenKeys  = $conf->{viewerHiddenKeys} || '';
     my @enabledKeys = ();
     my @keys        = qw(virtualHosts samlIDPMetaDataNodes samlSPMetaDataNodes
       applicationList oidcOPMetaDataNodes oidcRPMetaDataNodes
-      casSrvMetaDataNodes casAppMetaDataNodes
+      casSrvMetaDataNodes casAppMetaDataNodes sfExtra
       authChoiceModules grantSessionRules combModules
       openIdIDPList);
 
@@ -67,6 +93,7 @@ sub addRoutes {
 
       # Other keys
       ->addRoute( view => { ':cfgNum' => { '*' => 'viewKey' } }, ['GET'] );
+    return 1;
 }
 
 sub getConfByNum {
@@ -80,7 +107,8 @@ sub viewDiff {
     # Check Diff activation rule
     unless ( $self->diffRule->( $req, $req->{userData} ) ) {
         my $user = $req->{userData}->{_whatToTrace} || 'anonymous';
-        $self->userLogger->warn("$user tried to compare configurations!!!");
+        $self->userLogger->warn(
+            "$user is not authorized to compare configurations");
         return $self->sendJSONresponse( $req, { 'value' => '_Hidden_' } );
     }
 
@@ -144,7 +172,8 @@ sub viewKey {
             $self->logger->debug(
                 " $req->{env}->{REQUEST_URI} -> URI FORBIDDEN");
             my $user = $req->{userData}->{_whatToTrace} || 'anonymous';
-            $self->userLogger->warn("$user tried to browse configurations!!!");
+            $self->userLogger->warn(
+                "$user is not authorized to browse configurations");
             $self->rejectKey( $req, @args );
         }
     }
